module mdyLcdDispCircle( 
    clk_50m     ,  
    rst_n       , 

    lcd_hsync   ,
    lcd_vsync   ,
    lcd_de      ,
 

    lcd_rgb     ,
    lcd_dclk    
       
);

    input               clk_50m     ;  
    input               rst_n       ; 
    output              lcd_hsync   ;
    output              lcd_vsync   ;
    output              lcd_de      ;
    output  [23:0]      lcd_rgb     ;
    output              lcd_dclk    ;
 
    reg                 lcd_hsync   ;
    reg                 lcd_vsync   ;
    reg    [19:0]        distance   ; 
    reg     [23:0]      lcd_rgb     ;


 
    parameter     LINE_PR   =  1056 ;       
    parameter     FRAME_PER =   525 ;           

    parameter     H_SYNC    =    20 ;       
    parameter     V_SYNC    =    10 ;              

    parameter     HDE_START =    46 ;
    parameter     HDE_END   =   846 ;
    parameter     VDE_START =    23 ;
    parameter     VDE_END   =   503 ;
    

    reg    [12:0]     cnt_hys       ;
    reg    [12:0]     cnt_vys       ;
    reg               hsync_de      ;
    reg               vsync_de      ;
   

    wire              display_area  ;
    wire              e_area        ;
    wire              add_cnt_hys   ;
    wire              end_cnt_hys   ;
    wire              add_cnt_vys   ;
    wire              end_cnt_vys   ;
    reg    [ 7:0]        cnt0       ;
    wire              add_cnt0      ;
    wire              end_cnt0      ;
    reg    [15:0]       cnt1        ;
    wire              add_cnt1      ;
    wire              end_cnt1      ;


    assign clk       = clk_50m              ;
    assign lcd_dclk  = ~ clk_50m            ;
    assign lcd_de    = hsync_de & vsync_de  ;
    
 

    always @ (posedge clk or negedge rst_n)begin
            if(!rst_n)begin
                cnt_hys <= 0;
            end
            else if(add_cnt_hys)begin
                if(end_cnt_hys)
                    cnt_hys <= 0;
                else
                    cnt_hys <= cnt_hys + 1;
            end
        end
    
    assign add_cnt_hys = 1;
    assign end_cnt_hys = add_cnt_hys && cnt_hys == LINE_PR -1;
    

    always @ (posedge clk or negedge rst_n)begin
        if(!rst_n)begin
            cnt_vys <= 0;
        end
        else if(add_cnt_vys)begin
            if(end_cnt_vys)
                cnt_vys <= 0;
            else
                cnt_vys <= cnt_vys + 1;
        end
    end
   
    assign add_cnt_vys = end_cnt_hys;
    assign end_cnt_vys = add_cnt_vys && cnt_vys == FRAME_PER - 1;
	 
 

    always @ (posedge clk or negedge rst_n)begin
        if(!rst_n)begin
            lcd_hsync <= 1'b0 ;
        end
        else if(end_cnt_hys)begin
            lcd_hsync <= 1'b0;
        end
        else if(add_cnt_hys && cnt_hys == H_SYNC-1 )begin
            lcd_hsync <= 1'b1;
        end
    end


    always @ (posedge clk or negedge rst_n)begin
        if(!rst_n)begin
            hsync_de <= 1'b0;
        end
        else if(add_cnt_hys && cnt_hys == HDE_START-1)begin
            hsync_de <= 1'b1;
        end
        else if(add_cnt_hys && cnt_hys == HDE_END-1)begin
            hsync_de <= 1'b0;
        end
    end


	 
    always @ (posedge clk or negedge rst_n)begin
        if(!rst_n)begin
            lcd_vsync <= 1'b0 ;
        end
		  else if(add_cnt_vys && cnt_vys == V_SYNC-1 )begin
            lcd_vsync <= 1'b1;
        end
        else if(end_cnt_vys)begin
            lcd_vsync <= 1'b0;
        end

    end

	 
	 
    always @ (posedge clk or negedge rst_n)begin
        if(!rst_n)begin
            vsync_de <= 1'b0;
        end
        else if(add_cnt_vys && cnt_vys == VDE_START-1)begin
            vsync_de <= 1'b1;
        end
        else if(add_cnt_vys && cnt_vys ==VDE_END-1)begin
            vsync_de <= 1'b0;
        end
    end

	
    assign   display_area = hsync_de && vsync_de;

    always  @(*)begin
        distance= (cnt_hys-( HDE_START + 400)) *(cnt_hys-( HDE_START + 400))+(cnt_vys-( VDE_START +240)) *(cnt_vys-( VDE_START + 240));
    end

    always @ (posedge clk or negedge rst_n)begin
        if(!rst_n)begin
				lcd_rgb <= 0;
        end
        else if(display_area)begin
            if(distance<19600)begin
                lcd_rgb <= 24'h00_00_ff ;
            end
            else begin
                lcd_rgb <= 24'hff_ff_ff ;
            end
        end
        else begin
            lcd_rgb <= 0;
        end
    end



endmodule

